<?php

use CKPL\Pay\Exception\DecodedReturnException;

class ConotoxiaPaySuccessModuleFrontController extends ModuleFrontController
{
    /**
     * @throws PrestaShopDatabaseException
     * @throws PrestaShopException
     * @throws DecodedReturnException
     * @throws Exception
     */
    public function initContent()
    {
        parent::initContent();

        $urlReturnData = Tools::getValue('data');
        if (empty($urlReturnData)) {
            Tools::redirect('index.php');
        }

        try {
            /** @var CKPL\Pay\Pay $sdk */
            $sdk = $this->module->initializeConotoxiaPay();
            $decodedReturn = $sdk->payments()->decodeReturn($urlReturnData);
            $paymentId = $decodedReturn->getPaymentId();
            $orderId = $decodedReturn->getExternalPaymentId();

            $order = new Order($orderId);
            $validOrder = ConotoxiaPay::isValidOrder($order->getOrderPayments(), $paymentId);
        } catch (Exception $e) {
            PrestaShopLogger::addLog('ConotoxiaPay - success page problem: ' . $e->getMessage(), 3, $e->getCode(), 'Pay', null, true);
            $paymentId = null;
            $validOrder = false;
        }

        $this->renderPage($validOrder ? $decodedReturn->getResult() : 'OTHER', $paymentId);
    }

    /**
     * @param string $paymentResult
     * @param string $paymentId
     * @throws PrestaShopException
     */
    private function renderPage($paymentResult, $paymentId)
    {
        $this->context->smarty->assign([
            'smallLogo' => $this->module->getLogo(),
            'paymentId' => $paymentId,
            'paymentResult' => $paymentResult
        ]);
        $this->setTemplate(ConotoxiaPay::buildTemplatePath('payment_return'));
    }
}
